#ifndef TRAINEESVIEW_H
#define TRAINEESVIEW_H

#include "instructorsAndTrainees_global.h"
#include "commonview.h"

//Родительский класс представления БД Обучаемых (для просмотра и управления)

class TraineesView: public CommonView
{
    Q_OBJECT

public:
    TraineesView(InterfaceDataBaseLMS* dbLMS, TypeView type, QWidget *parent = nullptr);

protected:
    enum ColumnsTreeTrainees{        
        clmn_Trainee = 0,
        clmn_Login,
        clmn_Password,
        clmn_Class,
        clmn_Computer,
        clmn_IP_address,
        clmn_Archived,
        clmn_Logged,
        clmn_Tasks,
        clmn_ID
    };

public Q_SLOTS:
    //Слот обработки сигнала необходимости обновления интерфейса
    void slot_NeedUpdateUI(bool treeInstructor, bool treeTrainee);

protected:
    virtual void updateButtons(){};
    void preparationTreeWidget(/*QTreeWidget* tree*/);
    void loadTraineesFromDB();

    void reSetHeadTreeWidget();
};

#endif // TRAINEESVIEW_H
